Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(373)

Unified Diff: runtime/vm/raw_object_snapshot.cc

Issue 8761011: Renaming type classes as discussed: (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/raw_object_snapshot.cc
===================================================================
--- runtime/vm/raw_object_snapshot.cc (revision 1948)
+++ runtime/vm/raw_object_snapshot.cc (working copy)
@@ -140,29 +140,28 @@
}
-RawType* Type::ReadFrom(SnapshotReader* reader,
+RawAbstractType* AbstractType::ReadFrom(SnapshotReader* reader,
intptr_t object_id,
bool classes_serialized) {
- UNREACHABLE(); // Type is an abstract class.
+ UNREACHABLE(); // AbstractType is an abstract class.
return NULL;
}
-void RawType::WriteTo(SnapshotWriter* writer,
+void RawAbstractType::WriteTo(SnapshotWriter* writer,
intptr_t object_id,
bool serialize_classes) {
- UNREACHABLE(); // Type is an abstract class.
+ UNREACHABLE(); // AbstractType is an abstract class.
}
-RawParameterizedType* ParameterizedType::ReadFrom(SnapshotReader* reader,
+RawType* Type::ReadFrom(SnapshotReader* reader,
intptr_t object_id,
bool classes_serialized) {
ASSERT(reader != NULL);
// Allocate parameterized type object.
- ParameterizedType& parameterized_type =
- ParameterizedType::ZoneHandle(ParameterizedType::New());
+ Type& parameterized_type = Type::ZoneHandle(Type::New());
reader->AddBackwardReference(object_id, &parameterized_type);
// Set all non object fields.
@@ -180,7 +179,7 @@
}
-void RawParameterizedType::WriteTo(SnapshotWriter* writer,
+void RawType::WriteTo(SnapshotWriter* writer,
intptr_t object_id,
bool serialize_classes) {
ASSERT(writer != NULL);
@@ -190,7 +189,7 @@
writer->WriteObjectHeader(kInlined, object_id);
// Write out the class information.
- writer->WriteObjectHeader(kObjectId, Object::kParameterizedTypeClass);
+ writer->WriteObjectHeader(kObjectId, Object::kTypeClass);
// Write out all the non object pointer fields.
writer->Write<int8_t>(ptr()->type_state_);
@@ -310,7 +309,7 @@
TypeArray& type_array = TypeArray::Handle(TypeArray::New(len));
reader->AddBackwardReference(object_id, &type_array);
- Type& type = Type::Handle();
+ AbstractType& type = AbstractType::Handle();
for (intptr_t i = 0; i < len; i++) {
type ^= reader->ReadObject();
type_array.SetTypeAt(i, type);
« runtime/vm/raw_object.h ('K') | « runtime/vm/raw_object.cc ('k') | runtime/vm/scopes.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698